/*
 * Copyright 2011 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.jeffknecht.dynadao.annotation;

import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

import com.jeffknecht.dynadao.api.ColumnMapper;
import com.jeffknecht.dynadao.api.Generator;

/**
 * Identifies the column this property is associated with.
 * 
 * @author jeff.knecht
 */
@Target(ElementType.FIELD)
@Retention(RetentionPolicy.RUNTIME)
public @interface Column {
	/** The label of the database column */
	String value();
	
	/** If the label is different from the real source of the column, this 
	 * attribute identifies the real source of the data
	 */
	String derivedFrom() default "";
	
	/** Indicates whether this column is autoincremented by the database. (Optional default is false) */
	boolean autoIncrement() default false;
	
	/** Indicates whether this column is part of the primary key. Optional (default is false) */
	boolean primaryKey() default false;
	
	/** The SQL Type of the column.  Optional (default is 0) */
	int type() default 0;
	
	/** Indicates whether string values should be trimmed.  Optional (default is true) */
	boolean trim() default true;
	
	/** Indicates whether this column is used for optimistic locking.  Optional (default is false) */
	boolean optimisticLocking() default false;
	
	/** Which class is used to generate values for this column.  Optional */
	Class<? extends Generator> generator() default Generator.class;
	
	/** If a generator is specified, should it be executed on insert (default is false) */
	boolean generateOnInsert() default false;
	
	/** If a generator is specified, should it be executed on update (default is false) */
	boolean generateOnUpdate() default false;
	
	/** Which class is used to read values for this column.  Optional */
	Class<? extends ColumnMapper> columnMapper() default ColumnMapper.class;

}
