/*
 * Copyright 2011 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.jeffknecht.dynadao.annotation;

import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

/**
 * Specifies the source data of a DTO
 * as coming from a select statement
 * instead of a table.  Use in lieu
 * of Table annotation for complex,
 * read-only data types.
 * 
 * @author jeff.knecht
 */
@Target(ElementType.TYPE)
@Retention(RetentionPolicy.RUNTIME)
public @interface Select {
	/**
	 * A SQL FROM clause, without the keyword "from".
	 * 
	 * @return
	 */
	String from();
	
	/**
	 * A SQL WHERE clause, without the keyword "where".
	 */
	String where() default "";
	
	/**
	 * A SQL ORDER BY clause, without the keyword "order by".
	 */
	String orderBy() default "";

	/**
	 * A SQL GROUP BY clause, without the keyword "group by".
	 */
	String groupBy() default "";

	/**
	 * A SQL HAVING clause, without the keyword "having".
	 */
	String having() default "";

}
