/*
 * Copyright 2011 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.jeffknecht.dynadao.api;

import java.lang.reflect.Field;

/**
 * <p>When a column is tagged with a generator
 * class, the implementation of this interface
 * is responsible for generating a value for that
 * field.</p>
 * 
 * <p>In addition to implementing the methods defined
 * in this interface, the implementation
 * must provide a default constructor and must be thread-safe.</p>
 * 
 * @author jeff.knecht
 *
 */
public interface Generator {
	
	/**
	 * Indicates what kind of operation is currently being performed.
	 * 
	 * @author jeff.knecht
	 */
	public static enum Operation {
		INSERT,
		UPDATE
	}
	
	/**
	 * Implementers of this method must generate
	 * and set a value on the supplied field
	 * in the target object.
	 *  
	 * @param field The field whose value should be set
	 * @param target The object on which to set the value
	 * @param operation Indicates whether the operation is an insert or an update
	 */
	void generateValue(Field field, Object target, Operation operation) throws IllegalAccessException;
}
